@@ -11,7 +11,7 @@ use t::lib::Custom ();
 use t::lib::MyClass ();
 use t::lib::MyHtmlWindow ();
 
-our $VERSION = '0.68';
+our $VERSION = '0.69';
 our @ISA     = 'Wx::Dialog';
 
 sub new {
@@ -60,6 +60,13 @@ sub new {
 		Wx::Colour->new( 255, 128, 0 )
 	);
 
+	Wx::Event::EVT_CHAR(
+		$self->{m_textCtrl1},
+		sub {
+			$self->on_char($_[1]);
+		},
+	);
+
 	Wx::Event::EVT_TEXT(
 		$self,
 		$self->{m_textCtrl1},
@@ -430,6 +437,13 @@ sub new {
 		5,
 	);
 
+	Wx::Event::EVT_KEY_UP(
+		$self->{m_spinCtrl1},
+		sub {
+			$self->on_key_up($_[1]);
+		},
+	);
+
 	$self->{m_radioBox1} = Wx::RadioBox->new(
 		$self->{m_panel1},
 		-1,
@@ -907,6 +921,10 @@ sub m_htmlWin1 {
 	$_[0]->{m_htmlWin1};
 }
 
+sub on_char {
+	warn 'Handler method on_char for event m_textCtrl1.OnChar not implemented';
+}
+
 sub refresh {
 	warn 'Handler method refresh for event m_textCtrl1.OnText not implemented';
 }
@@ -927,6 +945,10 @@ sub list_item_selected {
 	warn 'Handler method list_item_selected for event m_listCtrl1.OnListItemSelected not implemented';
 }
 
+sub on_key_up {
+	warn 'Handler method on_key_up for event m_spinCtrl1.OnKeyUp not implemented';
+}
+
 sub on_radio_box {
 	warn 'Handler method on_radio_box for event m_radioBox1.OnRadioBox not implemented';
 }
